@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1997 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for c_incl/cache.c
  */
@@ -27,14 +27,13 @@
 #include <sys/stat.h>
 
 #include <main.h>
-#include <str.h>
-#include <word.h>
+#include <str_list.h>
 
 typedef struct cache_ty cache_ty;
 struct cache_ty
 {
 	struct stat	st;
-	wlist		ingredients;
+	string_list_ty	ingredients;
 };
 
 void cache_initialize _((void));
