@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1992, 1993, 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1992, 1993, 1994, 1997, 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,8 @@
  *	directive
  *
  * SYNOPSIS
- *	void directive(char *line, string_list_ty *type1, string_list_ty *type2);
+ *	void directive(char *line, string_list_ty *type1,
+ *		string_list_ty *type2);
  *
  * DESCRIPTION
  *	The directive function is used to scan a . line for an
@@ -51,7 +52,8 @@
  *	Just ignore anything we don't understand.
  */
 
-static void directive _((char *s, string_list_ty *type1, string_list_ty *type2));
+static void directive _((char *s, string_list_ty *type1,
+	string_list_ty *type2));
 
 static void
 directive(s, type1, type2)
@@ -112,7 +114,8 @@ directive(s, type1, type2)
  *	lang_roff_scan
  *
  * SYNOPSIS
- *	int lang_roff_scan(input_ty *fp, string_list_ty *type1, string_list_ty *type2);
+ *	int lang_roff_scan(input_ty *fp, string_list_ty *type1,
+ *		string_list_ty *type2);
  *
  * DESCRIPTION
  *	The lang_roff_scan function is used to scan a file looking
@@ -124,7 +127,7 @@ directive(s, type1, type2)
  *	fp	- file stream to scan
  *	type1	- list of <filenames>
  *	type2	- list of "filenames"
- *	
+ *
  * RETURNS
  *	int;	0 on success
  *		-1 on file errors
