@@ -31,4 +31,8 @@
 #include <sys/file.h>
 #endif
 
+#ifndef O_BINARY
+#define O_BINARY 0
+#endif
+
 #endif /* COMMON_AC_FCNTL_H */
