@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,6 @@
 #else
 
 #include <main.h>
-#define MOUNTED "/dev/null"
 
 struct mntent
 {
@@ -45,4 +44,12 @@ int endmntent _((FILE *));
 
 #endif /* !HAVE_MNTENT_H */
 
+/*
+ * On AIX, mntent.h doesn't define MOUNTED
+ * so this will be done on AIX, or on systems without mntent.h
+ */
+#ifndef MOUNTED
+#define MOUNTED "/dev/null"
+#endif
+
 #endif /* COMMON_AC_MNTENT_H */
