@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,12 +25,8 @@
 
 #include <config.h>
 
-#ifdef HAVE_winsize_SYS_IOCTL_H
-#include <sys/ioctl.h>
-#else
-#ifdef HAVE_winsize_TERMIOS_H
+#ifdef HAVE_TERMIOS_H
 #include <termios.h>
-#endif /* HAVE_winsize_TERMIOS_H */
-#endif /* !HAVE_winsize_SYS_IOCTL_H */
+#endif
 
 #endif /* COMMON_AC_TERMIOS_H */
