@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -80,4 +80,12 @@
 #define _BSD_SOURCE
 #endif
 
+#ifdef __PRIMOS__
+#define TIMESTAMP_GRANULARITY 4
+#elif __CYGWIN__
+#define TIMESTAMP_GRANULARITY 2
+#else
+#define TIMESTAMP_GRANULARITY 1
+#endif
+
 #endif /* COMMON_CONFIG_MESSY_H */
