@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,7 @@
 
 #include <main.h>
 
-void env_set _((char *name, char *value));
-void env_unset _((char *name));
+void env_set _((const char *name, const char *value));
+void env_unset _((const char *name));
 
 #endif /* COMMON_ENV_H */
