@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 2001 Peter Miller;
+ *	Copyright (C) 1997, 1998, 2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -29,6 +29,7 @@
 
 #include <error.h>
 #include <error_intl.h>
+#include <fflush_slow.h>
 #include <language.h>
 #include <page.h>
 #include <progname.h>
@@ -210,7 +211,7 @@ wrap(s)
 	 * so the error message appears in a sensible place.
 	 */
 	star_eoln();
-	if (fflush(stdout) || ferror(stdout))
+	if (fflush_slowly(stdout))
 		nfatal_raw("standard output");
 
 	/*
@@ -457,7 +458,7 @@ wrap(s)
 		 * terrible - stderr by default is character buffered.
 		 */
 		fputs(tmp, stderr);
-		if (ferror(stderr))
+		if (fflush_slowly(stderr))
 			break;
 
 		/*
@@ -476,7 +477,7 @@ wrap(s)
 	/*
 	 * make sure nothing went wrong
 	 */
-	if (fflush(stderr) || ferror(stderr))
+	if (fflush_slowly(stderr))
 		nfatal_raw("standard error");
 }
 
