@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,20 @@
 #include <error_intl.h>
 
 
+void
+error_intl_read(fn)
+	const char	*fn;
+{
+	sub_context_ty	*scp;
+
+	scp = sub_context_new();
+	sub_errno_set(scp);
+	sub_var_set(scp, "File_Name", "%s", fn);
+	error_intl(scp, i18n("read $filename: $errno"));
+	sub_context_delete(scp);
+}
+
+
 void
 fatal_intl_read(fn)
 	const char	*fn;
