@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1993, 1994, 1997, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1993, 1994, 1997, 2001, 2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -268,10 +268,10 @@ findsnake(depth, A, N, B, M)
 	long		M;
 {
 	snake_t		*sp;
-	long		ulx;
-	long		uly;
-	long		lrx;
-	long		lry;
+	long		ulx = 0;
+	long		uly = 0;
+	long		lrx = 0;
+	long		lry = 0;
 	long		D;
 	long		count;
 
