@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 2001 Peter Miller;
+ *	Copyright (C) 1997, 2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -57,8 +57,8 @@ static state_ty state;
 void
 language_init()
 {
-	char	*lib;
-	char	*package;
+	const char      *lib;
+	const char      *package;
 
 	if (state != state_uninitialized)
 		return;
@@ -88,7 +88,7 @@ language_init()
 #endif
 	lib = getenv("COOK_MESSAGE_LIBRARY");
 	if (!lib || !*lib)
-		lib = library_directory_get();
+		lib = configured_nlsdir();
 #ifdef HAVE_SETLOCALE
 #ifdef HAVE_GETTEXT
 	setlocale(LC_ALL, "");
