@@ -26,10 +26,10 @@
 #include <ac/stdarg.h>
 #include <main.h>
 
-char *mprintf _((char *fmt, ...));
-char *mprintfe _((char *fmt, ...));
-char *vmprintf _((char *fmt, va_list));
-char *vmprintfe _((char *fmt, va_list));
-struct string_ty *vmprintfes _((char *fmt, va_list));
+char *mprintf _((const char *fmt, ...));
+char *mprintfe _((const char *fmt, ...));
+char *vmprintf _((const char *fmt, va_list));
+char *vmprintfe _((const char *fmt, va_list));
+struct string_ty *vmprintfes _((const char *fmt, va_list));
 
 #endif /* COMMON_MPRINTF_H */
