@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 2001 Peter Miller;
+ *	Copyright (C) 1997, 2001, 2003, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,13 +24,13 @@
 #include <ac/string.h>
 #include <ac/time.h>
 
+#include <fflush_slow.h>
+#include <page.h>
 #include <progname.h>
 #include <quit.h>
 #include <star.h>
 #include <trace.h> /* for assert */
 
-#define PAGE_WIDTH 79
-
 static	int	previous;
 static	int	star_flag;
 static	int	star_col;
@@ -74,9 +74,12 @@ star_as_specified(c)
 {
 	int		immediate;
 	time_t		now;
+	static int	page_width;
 
 	if (!star_flag)
 		return;
+	if (!page_width)
+	    page_width = page_width_get() - 1;
 	if (c & STAR_IMMEDIATE)
 	{
 		c &= ~STAR_IMMEDIATE;
@@ -99,12 +102,12 @@ star_as_specified(c)
 	}
 	fputc(c, stderr);
 	star_col++;
-	if (star_col >= PAGE_WIDTH)
+	if (star_col >= page_width)
 	{
 		fputc('\n', stderr);
 		star_col = 0;
 	}
-	fflush(stderr);
+	fflush_slowly(stderr);
 	star_time = now + 1;
 }
 
@@ -133,7 +136,7 @@ star_eoln()
 	{
 		fputc('\n', stderr);
 		star_col = 0;
-		fflush(stderr);
+		fflush_slowly(stderr);
 	}
 	time(&now);
 	star_time = now + 1;
