@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -883,25 +883,6 @@ sub_getc(scp)
 			sub_diversion_close(scp);
 			continue;
 
-#if 0
-		case '%':
-			c = sub_getc_meta(scp);
-			if (c != '%')
-			{
-				sub_context_ty	*scp2;
-
-				scp2 = sub_context_new();
-				fatal_intl
-				(
-					scp2,
-		i18n("the %% character must always be doubled in substitutions")
-				);
-				/* NOTREACHED */
-				sub_context_delete(sc2);
-			}
-			break;
-#endif
-
 		case '$':
 			if (!scp->diversion->resubstitute)
 				break;
