@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1992, 1993, 1994, 1995, 1997, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1992-1995, 1997, 1999, 2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@
 #include <ac/stdarg.h>
 
 #include <error.h>
+#include <fflush_slow.h>
 #include <mem.h>
 #include <progname.h>
 #include <str.h>
@@ -172,10 +173,9 @@ trace_putchar(c)
 	case '\n':
 		*cp++ = '\n';
 		*cp = 0;
-		fflush(stdout);
+		fflush_slowly(stdout);
 		fputs(buffer, stderr);
-		fflush(stderr);
-		if (ferror(stderr))
+		if (fflush_slowly(stderr))
 			nfatal_raw("standard error");
 		cp = 0;
 		break;
