@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ void trace_enable _((char *));
 #define trace_stringize(x) "x"
 #endif
 
-void trace_string_real _((char *, char *));
+void trace_string_real _((const char *, const char *));
 void trace_short_unsigned_real _((char *, unsigned short *));
 void trace_short_real _((char *, short *));
 void trace_pointer_real _((char *, void *));
