@@ -70,6 +70,7 @@
 #include <builtin/pathname.h>
 #include <builtin/positional.h>
 #include <builtin/print.h>
+#include <builtin/read.h>
 #include <builtin/readlink.h>
 #include <builtin/relati_dirna.h>
 #include <builtin/resolve.h>
@@ -162,6 +163,8 @@ static builtin_ty *func[] =
 	&builtin_prepost,
 	&builtin_print,
 	&builtin_quote,
+	&builtin_read,
+	&builtin_read_lines,
 	&builtin_readlink,
 	&builtin_relative_dirname,
 	&builtin_reldir,
