@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994 Peter Miller.
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,19 +15,16 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for cook/builtin.c
  */
 
-#ifndef BUILTIN_H
-#define BUILTIN_H
+#ifndef COOK_BUILTIN_H
+#define COOK_BUILTIN_H
 
-#include <word.h>
-
-typedef int (*bifp)_((wlist *, wlist *));
+#include <main.h>
 
 void builtin_initialize _((void));
-bifp builtin_search _((string_ty *));
 
-#endif /* BUILTIN_H */
+#endif /* COOK_BUILTIN_H */
