@@ -31,7 +31,7 @@
 #include <error_intl.h>
 #include <expr/position.h>
 #include <option.h>
-#include <os.h>
+#include <os_interface.h>
 #include <star.h>
 #include <str_list.h>
 #include <trace.h>
