@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,6 +30,7 @@
 #include <error_intl.h>
 #include <expr/position.h>
 #include <match.h>
+#include <str_list.h>
 #include <trace.h>
 
 
@@ -53,15 +54,20 @@
  *	the result when it is finished, with a string_list_destructor() call.
  */
 
-int
-builtin_filter_out(result, args, pp, ocp)
+static int interpret _((string_list_ty *, const string_list_ty *,
+	const expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+interpret(result, args, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *args;
 	const expr_position_ty *pp;
 	const struct opcode_context_ty *ocp;
 {
 	int		j;
-	match_ty	*field;
+	match_ty	*mp;
+	int		retval;
+	int		retval2;
 
 	trace(("filter_out\n"));
 	assert(result);
@@ -82,15 +88,41 @@ builtin_filter_out(result, args, pp, ocp)
 		sub_context_delete(scp);
 		return -1;
 	}
+	retval = 0;
+	mp = match_new();
+	if (match_compile(mp, args->string[1], pp) < 0)
+	{
+		retval = -1;
+		goto error_ret;
+	}
 	for (j = 2; j < args->nstrings; j++)
 	{
-		field = match(args->string[1], args->string[j], pp);
-		if (field == MATCH_ERROR)
-			return -1;
-		if (field)
-			match_free(field);
-		else
+		retval2 = match_execute(mp, args->string[j], pp);
+		if (retval2 < 0)
+		{
+			retval = -1;
+			break;
+		}
+		if (!retval2)
 			string_list_append(result, args->string[j]);
 	}
-	return 0;
+	error_ret:
+	match_delete(mp);
+	return retval;
 }
+
+
+builtin_ty builtin_filter_out =
+{
+	"filter_out",
+	interpret,
+	interpret, /* script */
+};
+
+
+builtin_ty builtin_filter_out_ =
+{
+	"filter-out",
+	interpret,
+	interpret, /* script */
+};
