@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1991-1994, 1997-1999, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -88,7 +88,7 @@ look_for_exe(prog)
 		if (!suffix)
 			return 0;
 		s = str_format("%S%s", prog, suffix);
-		ok = os_exists(s);
+		ok = os_executable(s);
 		if (ok < 0)
 			ret_value = -1;
 		if (ok)
