@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,17 +23,13 @@
 #ifndef COOK_BUILTIN_MATCH_H
 #define COOK_BUILTIN_MATCH_H
 
-#include <main.h>
+#include <builtin/private.h>
 
-struct string_list_ty; /* existence */
-struct expr_position_ty; /* existence */
-struct opcode_context_ty; /* existence */
-
-int builtin_match _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
-int builtin_match_mask _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
-int builtin_fromto _((struct string_list_ty *, const struct string_list_ty *,
-	const struct expr_position_ty *, const struct opcode_context_ty *));
+extern builtin_ty builtin_match;
+extern builtin_ty builtin_matches;
+extern builtin_ty builtin_match_mask;
+extern builtin_ty builtin_filter;
+extern builtin_ty builtin_fromto;
+extern builtin_ty builtin_patsubst;
 
 #endif /* COOK_BUILTIN_MATCH_H */
