@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 
 #include <builtin/print.h>
 #include <error_intl.h>
-#include <quote.h>
 #include <str_list.h>
 #include <trace.h>
 
@@ -91,7 +90,7 @@ script(result, args, pp, ocp)
 	trace(("print::script(result = %08X, args = %08X)\n{\n",
 		result, args));
 	s = wl2str(args, 1, args->nstrings, (char *)0);
-	s2 = quote(s);
+	s2 = str_quote_shell(s);
 	str_free(s);
 	printf("echo %s\n", s2->str_text);
 	str_free(s2);
