@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,12 @@ cmp(va, vb)
 	b = *(string_ty **)vb;
 	da = 32767;
 	db = 32767;
-	tmp = cook_mtime_newest(cntx, b, &db, db) - cook_mtime_newest(cntx, a, &da, da);
+	tmp =
+		(
+			cook_mtime_newest(cntx, b, &db, db)
+		-
+			cook_mtime_newest(cntx, a, &da, da)
+		);
 	if (tmp == 0)
 		return 0;
 	return (tmp < 0 ? -1 : 1);
