@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,8 +23,8 @@
 #include <ac/ctype.h>
 
 #include <builtin/strip.h>
-#include <mem.h>
 #include <str_list.h>
+#include <stracc.h>
 
 
 static string_ty *strip _((string_ty *));
@@ -33,18 +33,11 @@ static string_ty *
 strip(s)
 	string_ty	*s;
 {
-	static char	*buf;
-	static size_t	bufmax;
-	char		*bp;
+	static stracc	sa;
 	char		*sp;
 	int		space;
 
-	if (bufmax < s->str_length)
-	{
-		bufmax = s->str_length;
-		buf = mem_change_size(buf, bufmax);
-	}
-	bp = buf;
+	sa_open(&sa);
 	sp = s->str_text;
 	while (*sp && isspace(*sp))
 		++sp;
@@ -56,18 +49,21 @@ strip(s)
 		else
 		{
 			if (space)
-				*bp++ = ' ';
-			*bp++ = *sp;
+				sa_char(&sa, ' ');
+			sa_char(&sa, *sp);
 			space = 0;
 		}
 		++sp;
 	}
-	return str_n_from_c(buf, bp - buf);
+	return sa_close(&sa);
 }
 
 
-int
-builtin_strip(result, arg, pp, ocp)
+static int interpret _((string_list_ty *, const string_list_ty *,
+	const struct expr_position_ty *, const struct opcode_context_ty *));
+
+static int
+interpret(result, arg, pp, ocp)
 	string_list_ty	*result;
 	const string_list_ty *arg;
 	const struct expr_position_ty *pp;
@@ -84,3 +80,11 @@ builtin_strip(result, arg, pp, ocp)
 	}
 	return 0;
 }
+
+
+builtin_ty builtin_strip =
+{
+	"strip",
+	interpret,
+	interpret, /* script */
+};
