@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999, 2001 Peter Miller;
+ *	Copyright (C) 1999, 2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 #include <builtin/write.h>
 #include <error_intl.h>
 #include <expr/position.h>
+#include <fflush_slow.h>
 #include <str_list.h>
 #include <trace.h>
 
@@ -123,7 +124,7 @@ interpret(result, args, pp, ocp)
 	/*
 	 * finish up writing the file
 	 */
-	if (fflush(fp))
+	if (fflush_slowly(fp))
 	{
 		error_intl_write(fn->str_text);
 		fclose(fp);
