@@ -141,6 +141,22 @@ fp_find_subdir(dirname, ok_to_read)
 }
 
 
+static symtab_ty *
+get_main_stp(void)
+{
+	if (!main_stp)
+	{
+		main_stp = symtab_alloc(100);
+		/*
+		 * DO NOT set main_stp->reap
+		 * as this will be done by fp_subdir_delete
+		 */
+		quit_handler_prio(fp_find_flush);
+	}
+	return main_stp;
+}
+
+
 /*
  * NAME
  *	fp_find_record
@@ -166,17 +182,8 @@ fp_find_record(path_a)
 	 * so do a quick lookup and see.
 	 */
 	trace(("fp_find_record(path = \"%s\")\n{\n", path_a->str_text));
-	if (!main_stp)
-	{
-		main_stp = symtab_alloc(100);
-		/*
-		 * DO NOT set main_stp->reap
-		 * as this will be done by fp_subdir_delete
-		 */
-		quit_handler_prio(fp_find_flush);
-	}
 	path_r = os_relative_if_possible(path_a);
-	p = symtab_query(main_stp, path_r);
+	p = symtab_query(get_main_stp(), path_r);
 	if (!p)
 	{
 		string_ty	*dirname;
@@ -295,7 +302,7 @@ fp_find_update(sdp, file, fp)
 	 * it away.  It could have been created recently, or delete
 	 * could have over-ridden it, etc.
 	 */
-	p = symtab_query(main_stp, filename);
+	p = symtab_query(get_main_stp(), filename);
 	if (p)
 	{
 		str_free(filename);
