@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999, 2001 Peter Miller;
+ *	Copyright (C) 1999, 2001, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -30,17 +30,20 @@
 typedef struct fp_value_ty fp_value_ty;
 struct fp_value_ty
 {
-	time_t		oldest;
-	time_t		newest;
-	string_ty	*contents_fingerprint;
-	string_ty	*ingredients_fingerprint;
+    time_t	    oldest;
+    time_t	    newest;
+    time_t	    stat_mod_time;
+    string_ty	    *contents_fingerprint;
+    string_ty	    *ingredients_fingerprint;
 };
 
 void fp_value_constructor _((fp_value_ty *));
 void fp_value_constructor_copy _((fp_value_ty *, const fp_value_ty *));
 void fp_value_constructor3 _((fp_value_ty *, time_t, time_t, string_ty *));
 void fp_value_constructor4 _((fp_value_ty *, time_t, time_t, string_ty *,
-	string_ty *));
+    string_ty *));
+void fp_value_constructor5 _((fp_value_ty *, time_t, time_t, time_t,
+    string_ty *, string_ty *));
 void fp_value_destructor _((fp_value_ty *));
 fp_value_ty *fp_value_new _((void));
 void fp_value_delete _((fp_value_ty *));
