@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997-1999, 2001, 2002 Peter Miller;
+ *	Copyright (C) 1997-1999, 2001-2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include <cascade.h>
 #include <cook.h>
 #include <desist.h>
+#include <error.h>
 #include <error_intl.h>
 #include <expr.h>
 #include <fingerprint/sync.h>
@@ -240,6 +241,7 @@ preference = %d)\n{\n"/*}*/,
 	string_list_append(wlp1, target1);
 	opcode_context_id_assign(ocp, id_target, id_variable_new(wlp1), -1);
 	string_list_delete(wlp1);
+	wlp1 = 0;
 
 	/*
 	 * Flags apply to the precondition and to the ingredients evaluation.
@@ -311,7 +313,7 @@ preference = %d)\n{\n"/*}*/,
 	wlp1 = opcode_context_run(ocp, rp->need1);
 	if (!wlp1)
 	{
-		error:
+		gci_error:
 		status = graph_build_status_error;
 		goto done;
 	}
@@ -400,7 +402,7 @@ backtrack:
 			if (inhibit < 0)
 			{
 				str_free(target2);
-				goto error;
+				goto gci_error;
 			}
 			if (inhibit)
 			{
@@ -441,7 +443,7 @@ backtrack:
 			sub_context_delete(scp);
 			gp->statistic.error_by_ingredient++;
 			str_free(target2);
-			goto error;
+			goto gci_error;
 
 		case graph_build_status_success:
 			string_list_append_unique(&need, target2);
@@ -461,7 +463,7 @@ backtrack:
 	if (!wlp2)
 	{
 		string_list_delete(wlp1);
-		goto error;
+		goto gci_error;
 	}
 	trace(("mark\n"));
 
@@ -523,7 +525,7 @@ backtrack:
 			if (inhibit < 0)
 			{
 				str_free(target2);
-				goto error;
+				goto gci_error;
 			}
 			if (inhibit)
 			{
@@ -571,7 +573,7 @@ backtrack:
 			sub_context_delete(scp);
 			gp->statistic.error_by_ingredient++;
 			str_free(target2);
-			goto error;
+			goto gci_error;
 
 		case graph_build_status_success:
 			string_list_append_unique(&need, target2);
@@ -597,11 +599,11 @@ backtrack:
 	{
 		for (j = 0; j < common_ingredients_gfl->nfiles; ++j)
 		{
-			string_list_append_unique
-			(
-				&need,
-				common_ingredients_gfl->item[j].file->filename
-			);
+			string_ty       *fn;
+
+			fn = common_ingredients_gfl->item[j].file->filename;
+			string_list_append_unique(&need, fn);
+			string_list_append_unique(wlp2, fn);
 		}
 		graph_file_list_nrc_append_list
 		(
@@ -674,7 +676,7 @@ backtrack:
 				);
 			match_delete(mp2);
 			if (inhibit < 0)
-				goto error;
+				goto gci_error;
 			if (inhibit)
 			{
 				rp->inhibit = 1;
@@ -720,10 +722,11 @@ backtrack:
 			);
 			sub_context_delete(scp);
 			gp->statistic.error_by_ingredient++;
-			goto error;
+			goto gci_error;
 
 		case graph_build_status_success:
 			string_list_append_unique(&need, target2);
+			string_list_append_unique(wlp2, target2);
 			graph_file_list_nrc_append
 			(
 				need_gfl,
@@ -772,7 +775,7 @@ backtrack:
 			string_list_delete(wlp1);
 			string_list_delete(wlp2);
 			gp->statistic.error_in_expr++;
-			goto error;
+			goto gci_error;
 
 		case 0:
 			if (option_test(OPTION_REASON))
@@ -800,20 +803,36 @@ backtrack:
 	 */
 	if (gp->file_pair)
 	{
-		graph_file_pair_remember_lists
-		(
-			gp->file_pair,
-			target,
-			wlp1,
-			&rp->pos
-		);
-		graph_file_pair_remember_lists
-		(
-			gp->file_pair,
-			target,
-			wlp2,
-			&rp->pos
-		);
+		for (k = 0; k < wlp1->nstrings; ++k)
+		{
+		    string_ty       *ingredient1;
+		    edge_type_ty    type1;
+
+		    edge_type_extract(wlp1->string[k], &ingredient1, &type1);
+		    graph_file_pair_remember_tlist
+		    (
+			    gp->file_pair,
+			    target,
+			    ingredient1,
+			    &rp->pos
+		    );
+		    str_free(ingredient1);
+		}
+		for (k = 0; k < wlp2->nstrings; ++k)
+		{
+		    string_ty       *ingredient2;
+		    edge_type_ty    type2;
+
+		    edge_type_extract(wlp2->string[k], &ingredient2, &type2);
+		    graph_file_pair_remember_tlist
+		    (
+			    gp->file_pair,
+			    target,
+			    ingredient2,
+			    &rp->pos
+		    );
+		    str_free(ingredient2);
+		}
 
 		/* remember cascaded ingredients */
 		for (j = 0; j < cascade.length; ++j)
@@ -1026,6 +1045,58 @@ preference = %d)\n{\n",
 	}
 	graph_file_list_nrc_destructor(&need_gfl);
 
+#ifdef DEBUG
+	/*
+	 * Make sure all of the targets and ingredients appear as file pairs.
+	 *
+	 * Q: Why not generate the pairs here?
+	 * A: Because by this point in the code, we have lost all
+	 * association with the location information necessary to generate
+	 * useful error messages.  And error messages is what the file
+	 * pair information is all about.
+	 */
+	if (gp->file_pair)
+	{
+	    size_t          j;
+	    int             ok;
+
+	    ok = 1;
+	    for (j = 0; j < grp->output->nfiles; ++j)
+	    {
+		string_ty       *target1;
+
+		target1 = grp->output->item[j].file->filename;
+		for (k = 0; k < grp->input->nfiles; ++k)
+		{
+		    string_ty       *ingredient;
+
+		    ingredient = grp->input->item[k].file->filename;
+		    if
+		    (
+			!graph_file_pair_exists
+			(
+			    gp->file_pair,
+			    target1,
+			    ingredient
+			)
+		    )
+		    {
+		        error_raw
+			(
+			    "%s: %d: file pair ''%S: %S'' missing",
+			    __FILE__,
+			    __LINE__,
+			    target1,
+			    ingredient
+			);
+			ok = 0;
+		    }
+		}
+	    }
+	    assert(ok);
+	}
+#endif
+
 	/*
 	 * return result
 	 */
