@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -49,7 +49,7 @@
  *	graph_walk_status_ty
  *		error		something went wrong
  *		uptodate	no work needed
- *		done_stop	work required		
+ *		done_stop	work required
  */
 
 graph_walk_status_ty
@@ -92,12 +92,16 @@ graph_recipe_check(grp, gp)
 	ocp = opcode_context_new(0, 0);
 	for (j = 0; j < grp->output->nfiles; ++j)
 	{
+		graph_file_and_type_ty *gftp2;
 		graph_file_ty	*gfp2;
 		time_t		age2;
 		long		depth2;
+		edge_type_ty	type2;
+
+		gftp2 = grp->output->item + j;
+		gfp2 = gftp2->file;
+		type2 = gftp2->edge_type;
 
-		gfp2 = grp->output->file[j];
-		
 		depth2 = 32767;
 		age2 = cook_mtime_newest(ocp, gfp2->filename, &depth2, depth2);
 		if (age2 < 0)
@@ -108,7 +112,7 @@ graph_recipe_check(grp, gp)
 		}
 		if (depth2 < target_depth)
 			target_depth = depth2;
-		if (!target_age || age2 < target_age)
+		if (!target_age || !(type2 & edge_type_exists))
 			target_age = age2;
 	}
 	if (target_age == 0)
@@ -120,11 +124,13 @@ graph_recipe_check(grp, gp)
 	need_age = 0;
 	for (j = 0; j < grp->input->nfiles; ++j)
 	{
+		graph_file_and_type_ty *gftp2;
 		graph_file_ty	*gfp2;
 		time_t		age2;
 		long		depth2;
 
-		gfp2 = grp->input->file[j];
+		gftp2 = grp->input->item + j;
+		gfp2 = gftp2->file;
 		depth2 = 32767;
 		age2 = cook_mtime_oldest(ocp, gfp2->filename, &depth2, depth2);
 		if (age2 < 0)
