@@ -25,6 +25,8 @@
 #include <id.h>
 #include <id/variable.h>
 #include <match/new_by_recip.h>
+#include <id/global.h>
+#include <opcode/context.h>
 #include <symtab.h>
 #include <str_list.h>
 
@@ -81,7 +83,7 @@ find_variable(name)
 	string_list_ty	*result;
 
 	key = str_from_c(name);
-	idp = id_search(key);
+	idp = symtab_query(id_global_stp(), key);
 	if (!idp)
 		return 0;
 	result = id_variable_query2(idp);
@@ -188,6 +190,7 @@ leaf_query(filename, probe)
 	leaf_ness_ty	*d;
 	time_t		t;
 	int		ok;
+	opcode_context_ty *ocp;
 
 	/*
 	 * Initialize if we need to.
@@ -269,7 +272,9 @@ leaf_query(filename, probe)
 	 * No accept form was given, so go and look in the file system.
 	 * Thus, existence implies leaf-ness.
 	 */
-	t = cook_mtime_oldest(filename, (long *)0, 32767L);
+	ocp = opcode_context_new(0, 0);
+	t = cook_mtime_oldest(ocp, filename, (long *)0, 32767L);
+	opcode_context_delete(ocp);
 	if (t < 0)
 		return leaf_ness_error;
 	if (t != 0)
