@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2000 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@
 #include <match.h>
 #include <mem.h>
 #include <option.h>
-#include <os.h>
+#include <os_interface.h>
 #include <recipe.h>
 #include <star.h>
 #include <stmt.h>
@@ -71,9 +71,12 @@ graph_recipe_new(rp)
 	grp->mp = 0;
 	grp->input = graph_file_list_nrc_new();
 	grp->output = graph_file_list_nrc_new();
+	grp->input_satisfied = 0;
+	grp->input_uptodate = 0;
 	grp->ocp = 0;
 	grp->single_thread = 0;
 	grp->host_binding = 0;
+	grp->multi_forced = 0;
 	trace(("return %08lX;\n", (long)grp));
 	trace((/*{*/"}\n"));
 	return grp;
