@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -68,6 +68,7 @@ graph_recipe_script(grp, gp)
 	size_t		j;
 	string_list_ty	wl;
 	int		forced;
+	long            file_pos = 0;
 
 	trace(("graph_recipe_script(grp = %08lX)\n{\n"/*}*/, (long)grp));
 	status = graph_walk_status_done;
@@ -229,6 +230,7 @@ graph_recipe_script(grp, gp)
 			str_free(js);
 		}
 		printf("\nthen\n");
+		file_pos = ftell(stdout);
 	}
 
 	/*
@@ -346,7 +348,12 @@ graph_recipe_script(grp, gp)
 
 		trace(("perform ``use'' clause\n"));
 		if (!forced)
+		{
+			if (file_pos == ftell(stdout))
+			    printf(":\n");
 			printf("else\n");
+			file_pos = ftell(stdout);
+		}
 		opcode_context_call(grp->ocp, grp->rp->up_to_date);
 		status2 = opcode_context_script(grp->ocp);
 		if (status2 != opcode_status_success)
@@ -357,7 +364,11 @@ graph_recipe_script(grp, gp)
 	 * finish the conditional around this recipe
 	 */
 	if (!forced)
+	{
+		if (file_pos == ftell(stdout))
+		    printf(":\n");
 		printf("fi\n");
+	}
 
 	/*
 	 * cancel the recipe flags
