@@ -42,12 +42,6 @@ struct id_ty
 
 void id_initialize _((void));
 void id_reset _((void));
-id_ty *id_search _((string_ty *));
-id_ty *id_search_fuzzy _((string_ty *, string_ty **));
-void id_assign _((string_ty *, id_ty *));
-void id_assign_push _((string_ty *, id_ty *));
-#define id_delete /-/-/-/
-void id_unassign _((string_ty *));
 void id_dump _((char *));
 
 int id_interpret _((id_ty *, struct opcode_context_ty *,
