@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,8 +34,10 @@ struct id_method_ty
 	char		*name;
 	int		size;
 	void		(*destructor)_((id_ty *));
-	int		(*interpret)_((id_ty *, struct opcode_context_ty *, const struct expr_position_ty *));
-	int		(*script)_((id_ty *, struct opcode_context_ty *, const struct expr_position_ty *));
+	int		(*interpret)_((id_ty *, struct opcode_context_ty *,
+				const struct expr_position_ty *));
+	int		(*script)_((id_ty *, struct opcode_context_ty *,
+				const struct expr_position_ty *));
 };
 
 id_ty *id_instance_new _((id_method_ty *));
