@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1993-1995, 1997-1999, 2001, 2003 Peter Miller;
+ *	Copyright (C) 1993-1995, 1997-1999, 2001, 2003, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -1590,6 +1590,12 @@ lex_cur_file()
 	return root->filename.logical;
 }
 
+string_ty *
+lex_cur_physical_file()
+{
+	assert(root);
+	return root->filename.physical;
+}
 
 int
 lex_cur_line()
