@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,8 @@ struct lex_filename_ty
 	struct string_ty *physical;
 };
 
-void lex_filename_constructor _((lex_filename_ty *, struct string_ty *, struct string_ty *));
+void lex_filename_constructor _((lex_filename_ty *, struct string_ty *,
+	struct string_ty *));
 lex_filename_ty *lex_filename_new _((struct string_ty *, struct string_ty *));
 void lex_filename_destructor _((lex_filename_ty *));
 void lex_filename_delete _((lex_filename_ty *));
