@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994-1999, 2001 Peter Miller;
+ *	Copyright (C) 1994-1999, 2001, 2003, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,40 @@
  *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: operating system start point, and command line argument parsing
+ *
+ *
+ * If you are going to add a new recipe flag (set by the "set" statement,
+ * or the "set" clause of a recipe) you need to change all of the
+ * following places:
+ *
+ * cook/option.h
+ *     to define the OPTION_ value
+ * cook/option.c
+ *     option_tidyup()
+ *         if the option defaults to true
+ *     option_set_errors()
+ *         if the option should be turned off once cookbook errors
+ *         are encountered.
+ *     option_number_name()
+ *         for the name of the option
+ * cook/flag.h
+ *     to define the RF_ values (RF stands for Recipe Flag)
+ * cook/flag.c
+ *     to define the RF_ names
+ * langu.flags.so
+ *     to document the recipe flag
+ *
+ * If you choose to make it a command line option,
+ * you must also update these files:
+ *
+ * cook/main.c
+ *     to define the new command line option and process it
+ *     (only if it should also be a command line option)
+ * cook/builtin/options.c
+ *     to access the option from within the cookbook (typically used
+ *     for recursive cook invokations)
+ * lib/en/man1/cook.1
+ *     to document it, if you added a new command line option
  */
 
 #include <ac/stddef.h>
@@ -30,6 +64,7 @@
 #include <builtin.h>
 #include <cook.h>
 #include <error_intl.h>
+#include <fflush_slow.h>
 #include <fingerprint.h>
 #include <help.h>
 #include <id.h>
@@ -92,6 +127,8 @@ enum
 	arglex_token_star_not,
 	arglex_token_strip_dot,
 	arglex_token_strip_dot_not,
+	arglex_token_tell_position,
+	arglex_token_tell_position_not,
 	arglex_token_touch,
 	arglex_token_touch_not,
 	arglex_token_tty,
@@ -159,6 +196,8 @@ static arglex_table_ty argtab[] =
 	{ "-No_STar",		(arglex_token_ty)arglex_token_star_not,	},
 	{ "-Strip_Dot",		(arglex_token_ty)arglex_token_strip_dot, },
 	{ "-No_Strip_Dot",	(arglex_token_ty)arglex_token_strip_dot_not, },
+	{ "-Tell_Position",	(arglex_token_ty)arglex_token_tell_position, },
+	{ "-No_Tell_Position", (arglex_token_ty)arglex_token_tell_position_not},
 	{ "-TErminal",		(arglex_token_ty)arglex_token_tty,	},
 	{ "-No_TErminal",	(arglex_token_ty)arglex_token_tty_not,	},
 	{ "-Touch",		(arglex_token_ty)arglex_token_touch,	},
@@ -389,6 +428,14 @@ argparse(level)
 			type = OPTION_SILENT;
 			goto normal_off;
 
+		case arglex_token_tell_position:
+			type = OPTION_TELL_POSITION;
+			goto normal_on;
+
+		case arglex_token_tell_position_not:
+			type = OPTION_TELL_POSITION;
+			goto normal_off;
+
 		case arglex_token_metering:
 			type = OPTION_METER;
 			goto normal_on;
@@ -761,6 +808,10 @@ main(argc, argv)
 	else
 		retval = cook(&option.o_target);
 
+#ifdef DEBUG
+	fflush_slowly_report();
+#endif
+
 	quit(retval);
 	/*NOTREACHED*/
 	return 0;
