@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998 Peter Miller;
+ *	Copyright (C) 1997, 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -116,7 +116,13 @@ execute(op, ocp)
 		break;
 
 	case 1:
-		opcode_context_id_assign(ocp, name->string[0], id_variable_new(value), 0);
+		opcode_context_id_assign
+		(
+			ocp,
+			name->string[0],
+			id_variable_new(value),
+			0
+		);
 		break;
 
 	default:
