@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1998 Peter Miller;
+ *	Copyright (C) 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -125,13 +125,13 @@ execute(op, ocp)
 		if (!idp)
 		{
 			string_ty	*other;
-	
+
 			status = opcode_status_error;
 			idp = opcode_context_id_search_fuzzy(ocp, Name, &other);
 			if (idp)
 			{
 				sub_context_ty	*scp;
-	
+
 				scp = sub_context_new();
 				sub_var_set(scp, "Name", "%S", Name);
 				sub_var_set(scp, "Guess", "%S", other);
@@ -146,7 +146,7 @@ execute(op, ocp)
 			else
 			{
 				sub_context_ty	*scp;
-	
+
 				scp = sub_context_new();
 				sub_var_set(scp, "Name", "%S", Name);
 				error_with_position
@@ -181,7 +181,13 @@ execute(op, ocp)
 		if (status == opcode_status_success)
 		{
 			string_list_append_list(value_pre, value);
-			opcode_context_id_assign(ocp, name->string[0], id_variable_new(value_pre), 0);
+			opcode_context_id_assign
+			(
+				ocp,
+				name->string[0],
+				id_variable_new(value_pre),
+				0
+			);
 		}
 		string_list_delete(value_pre);
 		break;
