@@ -405,30 +405,10 @@ spawn(args, input, pid_p, host_binding, ocp)
     }
     else
     {
-	int             magic_characters;
-
-	/*
-	 * see if there are any magic shell cheracters
-	 */
-	magic_characters = 0;
-	for (j = 0; j < args->nstrings; ++j)
-	{
-	    char            *s;
-
-	    for (s = args->string[j]->str_text; *s; ++s)
-	    {
-		if (strchr("#|=^();&<>*?[]:$`'\"\\\n", *s))
-		{
-		    magic_characters = 1;
-		    break;
-		}
-	    }
-	}
-
 	/*
 	 * build the command
 	 */
-	if (magic_characters)
+	if (os_execute_magic_characters_list(args))
 	{
 	    string_ty       *str;
 
