@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1993-1997, 1999, 2001, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -18,6 +18,40 @@
  *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for cook/option.c
+ *
+ *
+ * If you are going to add a new recipe flag (set by the "set" statement,
+ * or the "set" clause of a recipe) you need to change all of the
+ * following places:
+ *
+ * cook/option.h
+ *     to define the OPTION_ value
+ * cook/option.c
+ *     option_tidyup()
+ *         if the option defaults to true
+ *     option_set_errors()
+ *         if the option should be turned off once cookbook errors
+ *         are encountered.
+ *     option_number_name()
+ *         for the name of the option
+ * cook/flag.h
+ *     to define the RF_ values (RF stands for Recipe Flag)
+ * cook/flag.c
+ *     to define the RF_ names
+ * langu.flags.so
+ *     to document the recipe flag
+ *
+ * If you choose to make it a command line option,
+ * you must also update these files:
+ *
+ * cook/main.c
+ *     to define the new command line option and process it
+ *     (only if it should also be a command line option)
+ * cook/builtin/options.c
+ *     to access the option from within the cookbook (typically used
+ *     for recursive cook invokations)
+ * lib/en/man1/cook.1
+ *     to document it, if you added a new command line option
  */
 
 #ifndef OPTION_H
@@ -82,6 +116,7 @@ enum option_number_ty
 	OPTION_UPDATE,		/* update utime for consistency */
 	OPTION_UPDATE_MAX,	/* update utime for consistency - backwards! */
 	OPTION_MATCH_MODE_REGEX, /* regex pattern matching (as opp native) */
+	OPTION_TELL_POSITION,	/* add file and line when echoing commands */
 
 	/*
 	 * If you add to this list, make sure you also add the option to
