@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1995-2001 Peter Miller;
+ *	Copyright (C) 1995-2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -778,6 +778,34 @@ execute(cmd, fd, errok)
 }
 
 
+int
+os_execute_magic_characters(string_ty *s)
+{
+    const char      *cp;
+
+    cp = s->str_text;
+    while (*cp)
+    {
+	if (strchr("\t\n !\"#$&'()*:;<=>?[\\]^`|", *cp))
+    	    return 1;
+	++cp;
+    }
+    return 0;
+}
+
+
+int
+os_execute_magic_characters_list(string_list_ty *slp)
+{
+    size_t          j;
+
+    for (j = 0; j < slp->nstrings; ++j)
+	if (os_execute_magic_characters(slp->string[j]))
+	    return 1;
+    return 0;
+}
+
+
 /*
  * NAME
  *	os_execute - execute a command
@@ -801,7 +829,6 @@ os_execute(args, input, errok)
 	string_ty	*input;
 	int		errok;
 {
-	int		j;
 	int		fd;
 	int		retval;
 
@@ -848,58 +875,42 @@ os_execute(args, input, errok)
 		str_free(tfn);
 	}
 
-	for (j = 1; j < args->nstrings; j++)
+	if (os_execute_magic_characters_list(args))
 	{
-		char	*s;
+		string_ty	*str;
+		string_list_ty	newcmd;
+		char		*cp;
 
-		s = args->string[j]->str_text;
-		while (*s)
-		{
-			if (strchr("#|=^();&<>*?[]:$`'\"\\\n", *s))
-			{
-				string_ty	*str;
-				string_list_ty	newcmd;
-				char		*cp;
-
-				cp = getenv("SHELL");
-				if (!cp || !*cp)
-					cp = CONF_SHELL;
-				string_list_constructor(&newcmd);
-				str = str_from_c(cp);
-				string_list_append(&newcmd, str);
-				str_free(str);
-				if (option_test(OPTION_ERROK))
-					str = str_from_c("-c");
-				else
-					str = str_from_c("-ce");
-				string_list_append(&newcmd, str);
-				str_free(str);
-				str =
-					wl2str
-					(
-						args,
-						0,
-						args->nstrings - 1,
-						(char *)0
-					);
-				string_list_append(&newcmd, str);
-				str_free(str);
-				retval =
-					execute
-					(
-						&newcmd,
-						fd,
-						errok
-					);
-				string_list_destructor(&newcmd);
-				if (input)
-					close(fd);
-				return retval;
-			}
-			++s;
-		}
+		cp = getenv("SHELL");
+		if (!cp || !*cp)
+			cp = CONF_SHELL;
+		string_list_constructor(&newcmd);
+		str = str_from_c(cp);
+		string_list_append(&newcmd, str);
+		str_free(str);
+		if (option_test(OPTION_ERROK))
+			str = str_from_c("-c");
+		else
+			str = str_from_c("-ce");
+		string_list_append(&newcmd, str);
+		str_free(str);
+		str =
+			wl2str
+			(
+				args,
+				0,
+				args->nstrings - 1,
+				(char *)0
+			);
+		string_list_append(&newcmd, str);
+		str_free(str);
+		retval = execute(&newcmd, fd, errok);
+		string_list_destructor(&newcmd);
+	}
+	else
+	{
+		retval = execute(args, fd, errok);
 	}
-	retval = execute(args, fd, errok);
 	if (input)
 		close(fd);
 	ret:
@@ -1346,3 +1357,57 @@ os_mkdir(p, echo)
 			return 0;
 	}
 }
+
+
+int
+os_executable(string_ty *path)
+{
+    int             err;
+    sub_context_ty  *scp;
+
+    err = access(path->str_text, X_OK);
+    if (err != 0)
+    {
+	switch (errno)
+	{
+	case EACCES:
+	    /*
+	     * The requested access would be denied to the file or
+	     * search permission is denied to one of the directories
+	     * in pathname.
+	     */
+	    return 0;
+
+	case ENAMETOOLONG:
+	    /*
+	     * pathname is too long, therefore the file can't exist
+	     */
+	    return 0;
+
+	case ENOENT:
+	    /*
+	     * A directory component in pathname would have been
+	     * accessible but does not exist or was a dangling symbolic
+	     * link.
+	     */
+	    return 0;
+
+	case ENOTDIR:
+	    /*
+	     * A component used as a directory in pathname is not, in
+	     * fact, a directory.
+	     */
+	    return 0;
+
+	default:
+	    scp = sub_context_new();
+	    sub_errno_set(scp);
+	    sub_var_set(scp, "File_Name", "%S", path);
+	    error_intl(scp, i18n("access(\"$filename\", X_OK)"));
+	    sub_context_delete(scp);
+	    option_set_errors();
+	    return -1;
+	}
+    }
+    return 1;
+}
