@@ -20,7 +20,7 @@
  * MANIFEST: functions to manipulate below_dirs
  */
 
-#include <os.h>
+#include <os_interface.h>
 #include <os/below_dir.h>
 
 
