@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -57,7 +57,14 @@ os_dirname_relative(path)
 	if (cp)
 	{
 		if (cp > path->str_text)
-			path = str_n_from_c(path->str_text, cp - path->str_text);
+		{
+			path =
+				str_n_from_c
+				(
+					path->str_text,
+					cp - path->str_text
+				);
+		}
 		else
 			path = str_from_c("/");
 	}
