@@ -20,7 +20,7 @@
  * MANIFEST: functions to manipulate path_cats
  */
 
-#include <os.h>
+#include <os_interface.h>
 
 
 string_ty *
