@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1993-1995, 1997-1999, 2001, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,10 +34,44 @@ time_t os_mtime_oldest _((string_ty *));
 time_t os_mtime_newest _((string_ty *));
 int os_mtime_adjust _((string_ty *, time_t));
 int os_touch _((string_ty *));
+
+/**
+  * The os_execute_magic_characters function is used to determine if the
+  * given string contains any characters "magic" to the shell.
+  *
+  * \returns
+  *     zero if there are no magic characters, non-zero if there is at
+  *     least one magic character
+  */
+int os_execute_magic_characters _((string_ty *));
+
+/**
+  * The os_execute_magic_characters_list function is used to determine if the
+  * given list of string contains any characters "magic" to the shell.
+  *
+  * \returns
+  *     zero if there are no magic characters, non-zero if there is at
+  *     least one magic character
+  */
+int os_execute_magic_characters_list _((string_list_ty *));
+
 int os_execute _((string_list_ty *cmd, string_ty *input, int errok));
 int os_exists _((string_ty *));
 int os_exists_symlink _((string_ty *));
 int os_exists_dir _((string_ty *));
+
+/**
+  * The os_executable function is used to test if the given path exists
+  * and is executable.
+  *
+  * \param path
+  *     The path to test for existence and executablity.
+  * \returns
+  *     1 if exists and is executable, 0 if noes not exist, -1 on any
+  *     other error (the error has already been printed).
+  */
+int os_executable _((string_ty *path));
+
 string_ty *os_accdir _((void));
 string_ty *os_curdir _((void));
 string_ty *os_dirname _((string_ty *));
