@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -64,7 +64,8 @@ stmt_list_append(sl, s)
  *      void stmt_list_destructor(stmt_list_ty *);
  *
  *  DESCRIPTION
- *      The stmt_list_destructor function is used to free the list of statement trees.
+ *	The stmt_list_destructor function is used to free the list of
+ *	statement trees.
  *
  *  RETURNS
  *      void
