@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -41,4 +41,7 @@ void stmt_list_copy_constructor _((stmt_list_ty *, const stmt_list_ty *));
 void stmt_list_destructor _((stmt_list_ty *));
 void stmt_list_append _((stmt_list_ty *, struct stmt_ty *));
 
+stmt_list_ty *stmt_list_new _((void));
+void stmt_list_delete _((stmt_list_ty *));
+
 #endif /* COOK_STMT_LIST_H */
