@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997 Peter Miller;
+ *	Copyright (C) 1997, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 struct expr_list_ty; /* existence */
 struct expr_position_ty; /* existence */
 
-struct stmt_ty *stmt_set_new _((struct expr_list_ty *, struct expr_position_ty *));
+struct stmt_ty *stmt_set_new _((struct expr_list_ty *,
+	struct expr_position_ty *));
 
 #endif /* COOK_STMT_SET_H */
