@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1994-1999, 2001 Peter Miller;
+#	Copyright (C) 1994-1999, 2001, 2003 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -98,6 +98,8 @@ ${stem}.gen.\$(OBJEXT)"
 
 	lib/*/LC_MESSAGES/common.po)
 		;;
+	lib/*/LC_MESSAGES/fstrcmp.po)
+		;;
 
 	lib/*.po)
 		stem=`echo $file | sed 's|^lib/\(.*\)\.po$|\1|'`
@@ -136,6 +138,15 @@ ${stem}.gen.\$(OBJEXT)"
 		recursive_mkdir `dirname $src` `dirname $dst` datadir
 		;;
 
+	lib/*/building/*)
+		;;
+	lib/*/lsm/*)
+		;;
+	lib/*/readme/*)
+		;;
+	lib/*/release/*)
+		;;
+
 	lib/*/*/main.*)
 		stem=`echo $file | sed 's|^lib/\(.*\)/main.*$|\1|'`
 		groff_all="$groff_all lib/$stem.ps lib/$stem.dvi lib/$stem.txt"
