@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1993-1997, 1999, 2001, 2003 Peter Miller;
+#	Copyright (C) 1993-1997, 1999, 2001, 2003, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,8 @@ echo 'Group: Development/Building'
 echo "Source: http://www.canb.auug.org.au/~millerp/cook/cook-${version}.tar.gz"
 echo 'URL: http://www.canb.auug.org.au/~millerp/cook/'
 echo 'BuildRoot: /tmp/cook-build-root'
-echo 'Icon: cook.gif'
+echo 'Icon: cook-${version}/cook.gif'
+echo 'Provides: perl(host_lists.pl)'
 
 echo ''
 
