@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 2001, 2002 Peter Miller;
+ *	Copyright (C) 2001, 2002, 2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@
 #include <error_intl.h>
 
 int		warning;
-static int	limit;
+int             limit;
 static int	number_of_blank_lines;
 static int	number_of_errors;
 static int	line_number;
