@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1995, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1995, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -46,7 +46,12 @@ usage()
 	char		*progname;
 
 	progname = progname_get();
-	fprintf(stderr, "Usage: %s [ <option>... ] <string1> <string2>\n", progname);
+	fprintf
+	(
+		stderr,
+		"Usage: %s [ <option>... ] <string1> <string2>\n",
+		progname
+	);
 	fprintf(stderr, "       %s -VERSion\n", progname);
 	exit(1);
 }
@@ -95,7 +100,11 @@ main(argc, argv)
 				s2 = arglex_value.alv_string;
 			else
 			{
-				error_intl(0, i18n("too many strings specified"));
+				error_intl
+				(
+					0,
+					i18n("too many strings specified")
+				);
 				usage();
 			}
 			break;
