@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994 Peter Miller.
+ *	Copyright (C) 1994, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
  *
  *	You should have received a copy of the GNU General Public License
  *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  *
  * MANIFEST: interface definition for make2cook/lex.c
  */
@@ -25,12 +25,18 @@
 
 #include <main.h>
 
+struct string_ty; /* existence */
+struct sub_context_ty; /* existence */
+
 void lex_open _((char *));
 void lex_close _((void));
 
-void gram_error _((char *, ...));
+void gram_error _((char *));
+void lex_error _((struct sub_context_ty *, char *));
 void gram_trace _((char *, ...));
 void gram_trace2 _((void *, char *, ...));
 int gram_lex _((void));
 
+struct blob_ty *lex_blob _((struct string_ty *));
+
 #endif /* MAKE2COOK_LEX_H */
