@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -52,7 +52,8 @@ static arglex_table_ty argtab[] =
 	{ "-History_Commands", arglex_token_history_commands, },
 	{ "-Internal_Rules", arglex_token_internal_rules, },
 	{ "-Line_Numbers", arglex_token_line_numbers, },
-	{ "-No_Environment_variables", arglex_token_environment_variables_not, },
+	{ "-No_Environment_variables",
+		arglex_token_environment_variables_not, },
 	{ "-No_History_Commands", arglex_token_history_commands_not, },
 	{ "-No_Internal_Rules", arglex_token_internal_rules_not, },
 	{ "-No_Line_Numbers", arglex_token_line_numbers_not, },
@@ -91,11 +92,11 @@ main(argc, argv)
 	case arglex_token_help:
 		help((char *)0, usage);
 		exit(0);
-	
+
 	case arglex_token_version:
 		version();
 		exit(0);
-	
+
 	default:
 		break;
 	}
