@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -192,7 +192,13 @@ check_for_phony(this)
 	{
 		this->fake = fake_phony;
 		for (j = 0; j < this->ingredient->length; ++j)
-			string_list_append_unique(&phony, this->ingredient->list[j]->text);
+		{
+			string_list_append_unique
+			(
+				&phony,
+				this->ingredient->list[j]->text
+			);
+		}
 	}
 	trace((/*{*/"}\n"));
 }
@@ -219,7 +225,13 @@ check_for_precious(this)
 	{
 		this->fake = fake_precious;
 		for (j = 0; j < this->ingredient->length; ++j)
-			string_list_append_unique(&precious, this->ingredient->list[j]->text);
+		{
+			string_list_append_unique
+			(
+				&precious,
+				this->ingredient->list[j]->text
+			);
+		}
 	}
 	trace((/*{*/"}\n"));
 }
@@ -270,8 +282,16 @@ check_for_suffixes(this)
 	if (this->ingredient->length == 0)
 		string_list_destructor(&suffix);
 	else
+	{
 		for (j = 0; j < this->ingredient->length; ++j)
-			string_list_append_unique(&suffix, this->ingredient->list[j]->text);
+		{
+			string_list_append_unique
+			(
+				&suffix,
+				this->ingredient->list[j]->text
+			);
+		}
+	}
 	trace((/*{*/"}\n"));
 }
 
@@ -425,7 +445,7 @@ emit(that)
 		blob_emit(this->target->list[j]);
 	}
 	emit_char(':');
-	
+
 	for (j = 0; j < this->ingredient->length; ++j)
 	{
 		emit_char(' ');
@@ -754,19 +774,37 @@ stmt_rule_alloc(lhs, op, rhs, set, pred, single_thread)
 	trace(("mark\n"));
 	result = (stmt_rule_ty *)stmt_alloc(&method);
 	lhs2 = blob_list_alloc();
-	variable_rename_list(lhs, lhs2, &result->ref, VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE);
+	variable_rename_list
+	(
+		lhs,
+		lhs2,
+		&result->ref,
+		VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE
+	);
 	blob_list_free(lhs);
 	trace(("lhs2->length = %ld;\n", (long)lhs2->length));
 	assert(lhs2->length);
 
 	rhs2 = blob_list_alloc();
-	variable_rename_list(rhs, rhs2, &result->ref, VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE);
+	variable_rename_list
+	(
+		rhs,
+		rhs2,
+		&result->ref,
+		VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE
+	);
 	blob_list_free(rhs);
 
 	if (pred)
 	{
 		pred2 = blob_list_alloc();
-		variable_rename_list(pred, pred2, &result->ref, VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE);
+		variable_rename_list
+		(
+			pred,
+			pred2,
+			&result->ref,
+			VAREN_QUOTE_SPACES | VAREN_KNOW_ARCHIVE
+		);
 		blob_list_free(pred);
 		assert(pred2->length);
 	}
@@ -782,7 +820,13 @@ stmt_rule_alloc(lhs, op, rhs, set, pred, single_thread)
 
 		blp = blob_list_alloc();
 		stmt_rule_context((stmt_ty *)result);
-		variable_rename_list(single_thread, blp, &result->rref, VAREN_NO_FLAGS);
+		variable_rename_list
+		(
+			single_thread,
+			blp,
+			&result->rref,
+			VAREN_NO_FLAGS
+		);
 		blob_list_free(single_thread);
 		single_thread = blp;
 	}
@@ -1460,9 +1504,19 @@ stmt_rule_default(n)
 		ingredients = blob_list_alloc();
 		set = string_to_blob_list(tp->set, builtin, linum);
 		pred = 0;
-		single_thread = string_to_blob_list(tp->single_thread, builtin, linum);
+		single_thread =
+			string_to_blob_list(tp->single_thread, builtin, linum);
 
-		sp = stmt_rule_alloc(targets, 1, ingredients, set, pred, single_thread);
+		sp =
+			stmt_rule_alloc
+			(
+				targets,
+				1,
+				ingredients,
+				set,
+				pred,
+				single_thread
+			);
 
 		split_by_lines(tp->body, sp, builtin, linum);
 		trace((/*{*/"}\n"));
@@ -1517,8 +1571,15 @@ stmt_rule_default(n)
 						);
 				else
 					s = str_from_c(".a");
-				if (s->str_length && !string_list_member(&suffix, s))
+				if
+				(
+					s->str_length
+				&&
+					!string_list_member(&suffix, s)
+				)
+				{
 					ok = 0;
+				}
 				str_free(s);
 			}
 			string_list_destructor(&wl);
@@ -1551,11 +1612,22 @@ stmt_rule_default(n)
 		 */
 		++linum;
 		targets = string_to_blob_list(tp->target, builtin, linum);
-		ingredients = string_to_blob_list(tp->ingredients, builtin, linum);
+		ingredients =
+			string_to_blob_list(tp->ingredients, builtin, linum);
 		set = string_to_blob_list(tp->set, builtin, linum);
 		pred = 0;
-		single_thread = string_to_blob_list(tp->single_thread, builtin, linum);
-		sp = stmt_rule_alloc(targets, 1, ingredients, set, pred, single_thread);
+		single_thread =
+			string_to_blob_list(tp->single_thread, builtin, linum);
+		sp =
+			stmt_rule_alloc
+			(
+				targets,
+				1,
+				ingredients,
+				set,
+				pred,
+				single_thread
+			);
 		split_by_lines(tp->body, sp, builtin, linum);
 		trace((/*{*/"}\n"));
 		return sp;
