@@ -76,7 +76,7 @@ test2.in
 foobar
 if test $? -ne 0 ; then fail; fi
 
-cmp test.ok test.out
+diff test.ok test.out
 if test $? -ne 0 ; then fail; fi
 
 # probably OK
