@@ -20,6 +20,17 @@
 #
 # MANIFEST: Test the archive long name functionality
 #
+ed /dev/null > /dev/null 2>&1 << 'fubar'
+q
+fubar
+if test $? -ne 0; then
+	echo ''
+	echo '	Your system has no "ed" command.'
+	echo '	This test is declared to pass by default.'
+	echo ''
+	exit 0
+fi
+
 work=${COOK_TMP:-/tmp}/$$
 PAGER=cat
 export PAGER
@@ -72,7 +83,7 @@ cat > foo.ok << 'fubar'
 !<arch>
 fubar
 if test $? -ne 0 ; then fail; fi
-cmp foo.ok foo.aa > /dev/null 2>&1
+diff foo.ok foo.aa > /dev/null 2>&1
 if test $? -ne 0 ; then
 	echo ""
 	echo "	This system does not understand the standard text-based"
