@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1997, 1998 Peter Miller;
+#	Copyright (C) 1997, 1998, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -213,10 +213,10 @@ cat > test.ok << 'fubar'
 
 #!/bin/sh
 
-#line 21 "howto.cook"
+#line 21 howto.cook
 if test ! -e test
 then
-echo "not this time" 1>&2
+echo 'not this time' 1>&2
 exit 1
 fi
 exit 0
